@@ -1,5 +1,4 @@
 try:
-
     import logging
     import enum
     import traceback
@@ -9,11 +8,10 @@ try:
     from .token import Token
     from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
     from ...crm.api.util import APIHTTPConnector
-    from ..exception import SDKException
+    from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
     from ...crm.api.util.constants import Constants
 
 except Exception as e:
-
     import logging
     import enum
     import traceback
@@ -23,13 +21,13 @@ except Exception as e:
     from .token import Token
     from zcrmsdk.src.com.zoho.crm.api.initializer import Initializer
     from ...crm.api.util import APIHTTPConnector
-    from ..exception import SDKException
+    from zcrmsdk.src.com.zoho.crm.api.exception import SDKException
     from ...crm.api.util.constants import Constants
 
 
 class TokenType(enum.Enum):
     """
-    This class used to give token type.
+    This class contains different types of token.
     """
 
     GRANT = Constants.GRANT
@@ -39,7 +37,7 @@ class TokenType(enum.Enum):
 
 class OAuthToken(Token):
     """
-    This class to get tokens and check expire time.
+    This class maintains the tokens and authenticates every request.
     """
 
     logger = logging.getLogger('SDKLogger')
@@ -59,48 +57,45 @@ class OAuthToken(Token):
 
         error = {}
 
-        try:
+        if not isinstance(client_id, str):
+            error[Constants.FIELD] = Constants.CLIENT_ID
+            error[Constants.EXPECTED_TYPE] = Constants.STRING
+            error[Constants.CLASS] = OAuthToken.__name__
+            raise SDKException(code=Constants.TOKEN_ERROR, details=error)
 
-            if not isinstance(client_id, str):
-                error[Constants.FIELD] = Constants.CLIENT_ID
-                error[Constants.EXPECTED_TYPE] = Constants.STRING
-                error[Constants.CLASS] = OAuthToken.__name__
-                raise SDKException(Constants.TOKEN_ERROR, None, details=error, cause=traceback.format_stack(limit=6))
+        if client_secret is not None and not isinstance(client_secret, str):
+            error[Constants.FIELD] = Constants.CLIENT_SECRET
+            error[Constants.EXPECTED_TYPE] = Constants.STRING
+            error[Constants.CLASS] = OAuthToken.__name__
+            raise SDKException(code=Constants.TOKEN_ERROR, details=error)
 
-            if not isinstance(client_secret, str):
-                error[Constants.FIELD] = Constants.CLIENT_SECRET
-                error[Constants.EXPECTED_TYPE] = Constants.STRING
-                error[Constants.CLASS] = OAuthToken.__name__
-                raise SDKException(Constants.TOKEN_ERROR, None, details=error, cause=traceback.format_stack(limit=6))
+        if redirect_url is not None and not isinstance(redirect_url, str):
+            error[Constants.FIELD] = Constants.REDIRECT_URL
+            error[Constants.EXPECTED_TYPE] = Constants.STRING
+            error[Constants.CLASS] = OAuthToken.__name__
+            raise SDKException(code=Constants.TOKEN_ERROR, details=error)
 
-            if redirect_url is not None and not isinstance(redirect_url, str):
-                error[Constants.FIELD] = Constants.REDIRECT_URL
-                error[Constants.EXPECTED_TYPE] = Constants.STRING
-                error[Constants.CLASS] = OAuthToken.__name__
-                raise SDKException(Constants.TOKEN_ERROR, None, details=error, cause=traceback.format_stack(limit=6))
+        if not isinstance(token, str):
+            error[Constants.FIELD] = Constants.TOKEN
+            error[Constants.EXPECTED_TYPE] = Constants.STRING
+            error[Constants.CLASS] = OAuthToken.__name__
+            raise SDKException(code=Constants.TOKEN_ERROR, details=error)
 
-            if not isinstance(token, str):
-                error[Constants.FIELD] = Constants.TOKEN
-                error[Constants.EXPECTED_TYPE] = Constants.STRING
-                error[Constants.CLASS] = OAuthToken.__name__
-                raise SDKException(Constants.TOKEN_ERROR, None, details=error, cause=traceback.format_stack(limit=6))
+        if not isinstance(token_type, TokenType):
+            error[Constants.FIELD] = Constants.TOKEN_TYPE
+            error[Constants.EXPECTED_TYPE] = TokenType.__members__.keys()
+            error[Constants.CLASS] = OAuthToken.__name__
+            raise SDKException(code=Constants.TOKEN_ERROR, details=error)
 
-            if not isinstance(token_type, TokenType):
-                error[Constants.FIELD] = Constants.TOKEN_TYPE
-                error[Constants.EXPECTED_TYPE] = TokenType.__members__.keys()
-                error[Constants.CLASS] = OAuthToken.__name__
-                raise SDKException(Constants.TOKEN_ERROR, None, details=error, cause=traceback.format_stack(limit=6))
-
-            self.client_id = client_id
-            self.client_secret = client_secret
-            self.redirect_url = redirect_url
-            self.grant_token = token if (token_type == TokenType.GRANT) else None
-            self.refresh_token = token if (token_type == TokenType.REFRESH) else None
-            self.access_token = None
-            self.expires_in = None
-
-        except SDKException as ex:
-            raise ex
+        self.client_id = client_id
+        self.client_secret = client_secret
+        self.redirect_url = redirect_url
+        self.grant_token = token if (token_type == TokenType.GRANT) else None
+        self.refresh_token = token if (token_type == TokenType.REFRESH) else None
+        self.access_token = None
+        self.expires_in = None
+        self.user_mail = None
+        self.id = None
 
     def authenticate(self, url_connection):
         initializer = Initializer.get_initializer()
@@ -140,8 +135,7 @@ class OAuthToken(Token):
             raise ex
 
         except Exception as ex:
-            OAuthToken.logger.error(Constants.SAVE_TOKEN_ERROR + ex.__str__())
-            raise SDKException(None, None, None, cause=ex)
+            raise SDKException(code=Constants.SAVE_TOKEN_ERROR, cause=ex)
 
         return self
 
@@ -164,8 +158,7 @@ class OAuthToken(Token):
             raise ex
 
         except Exception as ex:
-            OAuthToken.logger.error(Constants.SAVE_TOKEN_ERROR + ex.__str__())
-            raise SDKException(None, None, None, cause=ex)
+            raise SDKException(code=Constants.SAVE_TOKEN_ERROR, cause=ex)
 
         return self
 
@@ -173,7 +166,6 @@ class OAuthToken(Token):
         response_json = dict(response)
 
         if Constants.ACCESS_TOKEN not in response_json:
-            OAuthToken.logger.error(Constants.GET_TOKEN_ERROR)
             raise SDKException(code=Constants.INVALID_CLIENT_ERROR, message=str(response_json.get(Constants.ERROR_KEY)))
 
         self.access_token = response_json.get(Constants.ACCESS_TOKEN)
@@ -187,3 +179,10 @@ class OAuthToken(Token):
     def get_token_expires_in(self, response):
         return int(response[Constants.EXPIRES_IN]) if Constants.EXPIRES_IN_SEC in response else int(
             response[Constants.EXPIRES_IN]) * 1000
+
+    def remove(self):
+        try:
+            Initializer.get_initializer().store.delete_token(self)
+            return True
+        except Exception:
+            return False
