@@ -2,8 +2,8 @@ from .action_wrapper import ActionWrapper
 from .api_exception import APIException
 from .action_response import ActionResponse
 from .response_handler import ResponseHandler
-from .attachments_operations import AttachmentsOperations,AttachmentsOperations,UploadLinkAttachmentParam
 from .attachment import Attachment
+from .attachments_operations import AttachmentsOperations, UploadLinkAttachmentParam, DeleteAttachmentsParam
 from .success_response import SuccessResponse
 from .file_body_wrapper import FileBodyWrapper
 from .response_wrapper import ResponseWrapper
