@@ -20,10 +20,10 @@ class AttachmentsOperations(object):
 			module_api_name (string) : A string representing the module_api_name
 		"""
 
-		if record_id is not None and not isinstance(record_id, int):
+		if not isinstance(record_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
 		
-		if module_api_name is not None and not isinstance(module_api_name, str):
+		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		self.__record_id = record_id
@@ -44,7 +44,7 @@ class AttachmentsOperations(object):
 			SDKException
 		"""
 
-		if id is not None and not isinstance(id, int):
+		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -78,7 +78,7 @@ class AttachmentsOperations(object):
 			SDKException
 		"""
 
-		if id is not None and not isinstance(id, int):
+		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
