@@ -20,7 +20,7 @@ class ContactRole(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -44,7 +44,7 @@ class ContactRole(object):
 		The method to get the name
 
 		Returns:
-			string: A string value
+			string: A string representing the name
 		"""
 
 		return self.__name
@@ -68,7 +68,7 @@ class ContactRole(object):
 		The method to get the sequence_number
 
 		Returns:
-			int: A int value
+			int: An int representing the sequence_number
 		"""
 
 		return self.__sequence_number
@@ -95,7 +95,7 @@ class ContactRole(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
