@@ -64,7 +64,7 @@ class Field(object):
 		The method to get the system_mandatory
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the system_mandatory
 		"""
 
 		return self.__system_mandatory
@@ -88,7 +88,7 @@ class Field(object):
 		The method to get the webhook
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the webhook
 		"""
 
 		return self.__webhook
@@ -141,7 +141,7 @@ class Field(object):
 		The method to get the content
 
 		Returns:
-			string: A string value
+			string: A string representing the content
 		"""
 
 		return self.__content
@@ -165,7 +165,7 @@ class Field(object):
 		The method to get the column_name
 
 		Returns:
-			string: A string value
+			string: A string representing the column_name
 		"""
 
 		return self.__column_name
@@ -189,7 +189,7 @@ class Field(object):
 		The method to get the type
 
 		Returns:
-			string: A string value
+			string: A string representing the type
 		"""
 
 		return self.__type
@@ -213,7 +213,7 @@ class Field(object):
 		The method to get the transition_sequence
 
 		Returns:
-			int: A int value
+			int: An int representing the transition_sequence
 		"""
 
 		return self.__transition_sequence
@@ -237,7 +237,7 @@ class Field(object):
 		The method to get the personality_name
 
 		Returns:
-			string: A string value
+			string: A string representing the personality_name
 		"""
 
 		return self.__personality_name
@@ -261,7 +261,7 @@ class Field(object):
 		The method to get the message
 
 		Returns:
-			string: A string value
+			string: A string representing the message
 		"""
 
 		return self.__message
@@ -285,7 +285,7 @@ class Field(object):
 		The method to get the mandatory
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the mandatory
 		"""
 
 		return self.__mandatory
@@ -367,7 +367,7 @@ class Field(object):
 		The method to get the json_type
 
 		Returns:
-			string: A string value
+			string: A string representing the json_type
 		"""
 
 		return self.__json_type
@@ -420,7 +420,7 @@ class Field(object):
 		The method to get the field_label
 
 		Returns:
-			string: A string value
+			string: A string representing the field_label
 		"""
 
 		return self.__field_label
@@ -473,7 +473,7 @@ class Field(object):
 		The method to get the created_source
 
 		Returns:
-			string: A string value
+			string: A string representing the created_source
 		"""
 
 		return self.__created_source
@@ -497,7 +497,7 @@ class Field(object):
 		The method to get the field_read_only
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the field_read_only
 		"""
 
 		return self.__field_read_only
@@ -521,7 +521,7 @@ class Field(object):
 		The method to get the display_label
 
 		Returns:
-			string: A string value
+			string: A string representing the display_label
 		"""
 
 		return self.__display_label
@@ -545,7 +545,7 @@ class Field(object):
 		The method to get the read_only
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the read_only
 		"""
 
 		return self.__read_only
@@ -598,7 +598,7 @@ class Field(object):
 		The method to get the quick_sequence_number
 
 		Returns:
-			int: A int value
+			int: An int representing the quick_sequence_number
 		"""
 
 		return self.__quick_sequence_number
@@ -622,7 +622,7 @@ class Field(object):
 		The method to get the businesscard_supported
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the businesscard_supported
 		"""
 
 		return self.__businesscard_supported
@@ -699,7 +699,7 @@ class Field(object):
 		The method to get the id
 
 		Returns:
-			int: A int value
+			int: An int representing the id
 		"""
 
 		return self.__id
@@ -723,7 +723,7 @@ class Field(object):
 		The method to get the custom_field
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the custom_field
 		"""
 
 		return self.__custom_field
@@ -776,7 +776,7 @@ class Field(object):
 		The method to get the visible
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the visible
 		"""
 
 		return self.__visible
@@ -800,7 +800,7 @@ class Field(object):
 		The method to get the length
 
 		Returns:
-			int: A int value
+			int: An int representing the length
 		"""
 
 		return self.__length
@@ -882,7 +882,7 @@ class Field(object):
 		The method to get the api_name
 
 		Returns:
-			string: A string value
+			string: A string representing the api_name
 		"""
 
 		return self.__api_name
@@ -935,7 +935,7 @@ class Field(object):
 		The method to get the history_tracking
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the history_tracking
 		"""
 
 		return self.__history_tracking
@@ -959,7 +959,7 @@ class Field(object):
 		The method to get the data_type
 
 		Returns:
-			string: A string value
+			string: A string representing the data_type
 		"""
 
 		return self.__data_type
@@ -1012,7 +1012,7 @@ class Field(object):
 		The method to get the decimal_place
 
 		Returns:
-			int: A int value
+			int: An int representing the decimal_place
 		"""
 
 		return self.__decimal_place
@@ -1036,7 +1036,7 @@ class Field(object):
 		The method to get the mass_update
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the mass_update
 		"""
 
 		return self.__mass_update
@@ -1060,7 +1060,7 @@ class Field(object):
 		The method to get the blueprint_supported
 
 		Returns:
-			bool: A bool value
+			bool: A bool representing the blueprint_supported
 		"""
 
 		return self.__blueprint_supported
@@ -1166,7 +1166,7 @@ class Field(object):
 		The method to get the default_value
 
 		Returns:
-			string: A string value
+			string: A string representing the default_value
 		"""
 
 		return self.__default_value
@@ -1190,7 +1190,7 @@ class Field(object):
 		The method to get the section_id
 
 		Returns:
-			int: A int value
+			int: An int representing the section_id
 		"""
 
 		return self.__section_id
@@ -1265,7 +1265,7 @@ class Field(object):
 			key (string) : A string representing the key
 
 		Returns:
-			int: A int value
+			int: An int representing the modification
 		"""
 
 		if key is not None and not isinstance(key, str):
