@@ -59,7 +59,7 @@ class ModulesOperations(object):
 			SDKException
 		"""
 
-		if api_name is not None and not isinstance(api_name, str):
+		if not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -98,7 +98,7 @@ class ModulesOperations(object):
 		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if api_name is not None and not isinstance(api_name, str):
+		if not isinstance(api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -139,7 +139,7 @@ class ModulesOperations(object):
 		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if id is not None and not isinstance(id, int):
+		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
