@@ -25,13 +25,13 @@ class RelatedRecordsOperations(object):
 			related_list_api_name (string) : A string representing the related_list_api_name
 		"""
 
-		if module_api_name is not None and not isinstance(module_api_name, str):
+		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if record_id is not None and not isinstance(record_id, int):
+		if not isinstance(record_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
 		
-		if related_list_api_name is not None and not isinstance(related_list_api_name, str):
+		if not isinstance(related_list_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: related_list_api_name EXPECTED TYPE: str', None, None)
 		
 		self.__module_api_name = module_api_name
@@ -176,7 +176,7 @@ class RelatedRecordsOperations(object):
 		if header_instance is not None and not isinstance(header_instance, HeaderMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: header_instance EXPECTED TYPE: HeaderMap', None, None)
 		
-		if related_record_id is not None and not isinstance(related_record_id, int):
+		if not isinstance(related_record_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: related_record_id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -223,7 +223,7 @@ class RelatedRecordsOperations(object):
 		if request is not None and not isinstance(request, BodyWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: BodyWrapper', None, None)
 		
-		if related_record_id is not None and not isinstance(related_record_id, int):
+		if not isinstance(related_record_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: related_record_id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -262,7 +262,7 @@ class RelatedRecordsOperations(object):
 			SDKException
 		"""
 
-		if related_record_id is not None and not isinstance(related_record_id, int):
+		if not isinstance(related_record_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: related_record_id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
