@@ -156,7 +156,7 @@ class TagsOperations(object):
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if id is not None and not isinstance(id, int):
+		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -189,7 +189,7 @@ class TagsOperations(object):
 			SDKException
 		"""
 
-		if id is not None and not isinstance(id, int):
+		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -228,7 +228,7 @@ class TagsOperations(object):
 		if request is not None and not isinstance(request, MergeWrapper):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: request EXPECTED TYPE: MergeWrapper', None, None)
 		
-		if id is not None and not isinstance(id, int):
+		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -267,10 +267,10 @@ class TagsOperations(object):
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if module_api_name is not None and not isinstance(module_api_name, str):
+		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if record_id is not None and not isinstance(record_id, int):
+		if not isinstance(record_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -310,10 +310,10 @@ class TagsOperations(object):
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if module_api_name is not None and not isinstance(module_api_name, str):
+		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
-		if record_id is not None and not isinstance(record_id, int):
+		if not isinstance(record_id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: record_id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -352,7 +352,7 @@ class TagsOperations(object):
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if module_api_name is not None and not isinstance(module_api_name, str):
+		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -389,7 +389,7 @@ class TagsOperations(object):
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if module_api_name is not None and not isinstance(module_api_name, str):
+		if not isinstance(module_api_name, str):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: module_api_name EXPECTED TYPE: str', None, None)
 		
 		handler_instance = CommonAPIHandler()
@@ -426,7 +426,7 @@ class TagsOperations(object):
 		if param_instance is not None and not isinstance(param_instance, ParameterMap):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: param_instance EXPECTED TYPE: ParameterMap', None, None)
 		
-		if id is not None and not isinstance(id, int):
+		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
