@@ -48,7 +48,7 @@ class TerritoriesOperations(object):
 			SDKException
 		"""
 
-		if id is not None and not isinstance(id, int):
+		if not isinstance(id, int):
 			raise SDKException(Constants.DATA_TYPE_ERROR, 'KEY: id EXPECTED TYPE: int', None, None)
 		
 		handler_instance = CommonAPIHandler()
