@@ -214,10 +214,12 @@ class Constants(object):
 
     REMINDAT_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.RemindAt"
 
-    LINETAX = "zcrmsdk.src.com.zoho.crm.api.record.LineTax"
+    LINE_TAX_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.LineTax"
 
     REMINDER_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.Reminder"
 
+    ATTACHMENTS_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.attachments.Attachment"
+
     RECURRING_ACTIVITY_NAMESPACE = "zcrmsdk.src.com.zoho.crm.api.record.RecurringActivity"
 
     PARTICIPANTS = "zcrmsdk.src.com.zoho.crm.api.record.Participants"
@@ -256,6 +258,8 @@ class Constants(object):
 
     TOKEN = "token"
 
+    USER_PROXY = "proxy"
+
     JSON_DETAILS_FILE_PATH = 'json_details.json'
 
     EMAIL = "email"
@@ -400,6 +404,8 @@ class Constants(object):
 
     HTTP = "http"
 
+    HTTPS = "https"
+
     CONTENT_API_URL = "content.zohoapis.com"
 
     EXCEPTION = "Exception"
@@ -452,4 +458,45 @@ class Constants(object):
 
     INITIALIZATION_EXCEPTION = "Exception in initialization"
 
+    SWITCH_USER_EXCEPTION = "Exception in switching user"
+
     AUTO_REFRESH_FIELDS_ERROR_MESSAGE = "auto_refresh_fields MUST NOT be None."
+
+    HEADER_NONE_ERROR = "NONE HEADER ERROR"
+
+    HEADER_INSTANCE_NONE_ERROR = "Header Instance MUST NOT be None"
+
+    PARAM_INSTANCE_NONE_ERROR = "Param Instance MUST NOT be None"
+
+    HEADER_NAME_NONE_ERROR = "NONE HEADER NAME ERROR"
+
+    HEADER_NAME_NULL_ERROR_MESSAGE = "Header Name MUST NOT be null"
+
+    NONE_VALUE_ERROR_MESSAGE = " MUST NOT be None"
+
+    PARAMETER_NONE_ERROR = "NONE PARAMETER ERROR"
+
+    PARAM_NAME_NONE_ERROR = "NONE PARAM NAME ERROR"
+
+    PARAM_NAME_NONE_ERROR_MESSAGE = "Param Name MUST NOT be None"
+
+    SWITCH_USER_ERROR = "SWITCH USER ERROR"
+
+    USER_PROXY_ERROR = "USERPROXY ERROR"
+
+    HOST_ERROR_MESSAGE = "Host MUST NOT be None"
+
+    PORT_ERROR_MESSAGE = "Port MUST NOT be None"
+
+    USER_ERROR_MESSAGE = "User MUST NOT be None/empty"
+
+    UNSUPPORTED_IN_API = "API UNSUPPORTED OPERATION"
+
+    UNSUPPORTED_IN_API_MESSAGE = " Operation is not supported by API"
+
+    NULL_VALUE = "null"
+
+    NOTES = "notes"
+
+    ATTACHMENTS = "$attachments"
+
